@@ -29,19 +29,59 @@
 #include <QtGui/QStyleOptionViewItemV4>
 #include <QtGui/QTreeView>
 
+#include "entitytreemodel.h"
+#include "collectionstatistics.h"
+#include "collection.h"
+#include "progressspinnerdelegate_p.h"
+
 using namespace Akonadi;
 
 namespace Akonadi {
 
+enum CountType
+{
+  UnreadCount,
+  TotalCount
+};
+
 class CollectionStatisticsDelegatePrivate
 {
   public:
     QTreeView *parent;
     bool drawUnreadAfterFolder;
+    DelegateAnimator *animator;
+    QColor mSelectedUnreadColor;
+    QColor mDeselectedUnreadColor;
 
     CollectionStatisticsDelegatePrivate( QTreeView *treeView )
-        : parent( treeView ), drawUnreadAfterFolder( false )
+        : parent( treeView ),
+          drawUnreadAfterFolder( false ),
+          animator( 0 )
     {
+      mSelectedUnreadColor = KColorScheme( QPalette::Active, KColorScheme::Selection )
+                                         .foreground( KColorScheme::LinkText ).color();
+      mDeselectedUnreadColor = KColorScheme( QPalette::Active, KColorScheme::View )
+                                           .foreground( KColorScheme::LinkText ).color();
+    }
+
+    template<CountType countType>
+    qint64 getCountRecursive( const QModelIndex &index ) const
+    {
+      Collection collection = qvariant_cast<Collection>( index.data( EntityTreeModel::CollectionRole ) );
+      Q_ASSERT( collection.isValid() );
+      CollectionStatistics statistics = collection.statistics();
+      qint64 count = qMax( 0LL, countType == UnreadCount ? statistics.unreadCount() : statistics.count() );
+
+      if ( index.model()->hasChildren( index ) )
+      {
+        const int rowCount = index.model()->rowCount( index );
+        for ( int row = 0; row < rowCount; row++ )
+        {
+          static const int column = 0;
+          count += getCountRecursive<countType>( index.model()->index( row, column, index ) );
+        }
+      }
+      return count;
     }
 };
 
@@ -51,6 +91,7 @@ CollectionStatisticsDelegate::CollectionStatisticsDelegate( QTreeView *parent )
   : QStyledItemDelegate( parent ),
     d_ptr( new CollectionStatisticsDelegatePrivate( parent ) )
 {
+
 }
 
 CollectionStatisticsDelegate::~CollectionStatisticsDelegate()
@@ -70,20 +111,85 @@ bool CollectionStatisticsDelegate::unreadCountShown() const
   return d->drawUnreadAfterFolder;
 }
 
+void CollectionStatisticsDelegate::setProgressAnimationEnabled( bool enable )
+{
+  Q_D( CollectionStatisticsDelegate );
+  if ( enable == ( d->animator != 0 ) )
+      return;
+  if ( enable ) {
+    Q_ASSERT( !d->animator );
+    Akonadi::DelegateAnimator *animator = new Akonadi::DelegateAnimator( d->parent );
+    d->animator = animator;
+  } else {
+    delete d->animator;
+    d->animator = 0;
+  }
+}
+
+bool CollectionStatisticsDelegate::progressAnimationEnabled() const
+{
+  Q_D( const CollectionStatisticsDelegate );
+  return d->animator != 0;
+}
+
 void CollectionStatisticsDelegate::initStyleOption( QStyleOptionViewItem *option,
                                                     const QModelIndex &index ) const
 {
+  Q_D( const CollectionStatisticsDelegate );
+
   QStyleOptionViewItemV4 *noTextOption =
       qstyleoption_cast<QStyleOptionViewItemV4 *>( option );
   QStyledItemDelegate::initStyleOption( noTextOption, index );
   noTextOption->text.clear();
+
+  if ( d->animator ) {
+
+    const Akonadi::Collection collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+
+    if (!collection.isValid())
+    {
+      d->animator->pop(index);
+      return;
+    }
+
+    if (index.data(Akonadi::EntityTreeModel::FetchStateRole).toInt() != Akonadi::EntityTreeModel::FetchingState)
+    {
+      d->animator->pop(index);
+      return;
+    }
+
+    d->animator->push(index);
+
+    if (QStyleOptionViewItemV4 *v4 = qstyleoption_cast<QStyleOptionViewItemV4 *>(option)) {
+      v4->icon = d->animator->sequenceFrame(index);
+    }
+  }
 }
 
+class PainterStateSaver
+{
+  public:
+    PainterStateSaver( QPainter *painter )
+    {
+      mPainter = painter;
+      mPainter->save();
+    }
+
+    ~PainterStateSaver()
+    {
+      mPainter->restore();
+    }
+
+  private:
+    QPainter *mPainter;
+};
+
 void CollectionStatisticsDelegate::paint( QPainter *painter,
                                           const QStyleOptionViewItem &option,
                                           const QModelIndex &index ) const
 {
   Q_D( const CollectionStatisticsDelegate );
+  PainterStateSaver stateSaver( painter );
 
   // First, paint the basic, but without the text. We remove the text
   // in initStyleOption(), which gets called by QStyledItemDelegate::paint().
@@ -106,36 +212,34 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
   bool expanded = d->parent->isExpanded( firstColumn );
 
   if ( option.state & QStyle::State_Selected ) {
-    painter->save();
     painter->setPen( option.palette.highlightedText().color() );
   }
 
+  Collection collection = index.sibling( index.row(), 0 ).data( EntityTreeModel::CollectionRole ).value<Collection>();
+
+  Q_ASSERT(collection.isValid());
+
+  CollectionStatistics statistics = collection.statistics();
+
+  qint64 unreadCount = qMax( 0LL, statistics.unreadCount() );
+  qint64 unreadRecursiveCount = d->getCountRecursive<UnreadCount>( index.sibling( index.row(), 0 ) );
+
   // Draw the unread count after the folder name (in parenthesis)
   if ( d->drawUnreadAfterFolder && index.column() == 0 ) {
-
-    QVariant unreadCount = index.model()->data( index,
-                           CollectionStatisticsModel::UnreadRole );
-    QVariant unreadRecursiveCount = index.model()->data( index,
-                           CollectionStatisticsModel::RecursiveUnreadRole );
-    Q_ASSERT( unreadCount.type() == QVariant::LongLong );
-    Q_ASSERT( unreadRecursiveCount.type() == QVariant::LongLong );
-
     // Construct the string which will appear after the foldername (with the
     // unread count)
     QString unread;
-    QString unreadCountInChilds = QString::number( unreadRecursiveCount.toLongLong() -
-                                                   unreadCount.toLongLong() );
-    if ( expanded && unreadCount.toLongLong() > 0 )
-      unread = QString( QLatin1String(" (%1)") ).arg( unreadCount.toLongLong() );
+//     qDebug() << expanded << unreadCount << unreadRecursiveCount;
+    if ( expanded && unreadCount > 0 )
+      unread = QString( QLatin1String( " (%1)" ) ).arg( unreadCount );
     else if ( !expanded ) {
-      if ( unreadCount.toLongLong() != unreadRecursiveCount.toLongLong() )
-        unread = QString( QLatin1String(" (%1 + %2)") ).arg( unreadCount.toString(),
-                                                             unreadCountInChilds );
-      else if ( unreadCount.toLongLong() > 0 )
-        unread = QString( QLatin1String(" (%1)") ).arg( unreadCount.toString() );
+      if ( unreadCount != unreadRecursiveCount )
+        unread = QString( QLatin1String( " (%1 + %2)" ) ).arg( unreadCount ).arg( unreadRecursiveCount - unreadCount );
+      else if ( unreadCount > 0 )
+        unread = QString( QLatin1String( " (%1)" ) ).arg( unreadCount );
     }
 
-    painter->save();
+    PainterStateSaver stateSaver( painter );
 
     if ( !unread.isEmpty() ) {
       QFont font = painter->font();
@@ -160,17 +264,11 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
 
     // Draw folder name and unread count
     painter->drawText( folderRect, Qt::AlignLeft, folderName );
-    KColorScheme::ColorSet cs = ( option.state & QStyle::State_Selected ) ?
-                                 KColorScheme::Selection : KColorScheme::View;
-    QColor unreadColor = KColorScheme( QPalette::Active, cs ).
-                                   foreground( KColorScheme::LinkText ).color();
+
+    const QColor unreadColor = (option.state & QStyle::State_Selected) ? d->mSelectedUnreadColor : d->mDeselectedUnreadColor;
     painter->setPen( unreadColor );
     painter->drawText( unreadRect, Qt::AlignLeft, unread );
-    painter->restore();
 
-    if ( option.state & QStyle::State_Selected ) {
-      painter->restore();
-    }
     return;
   }
 
@@ -178,50 +276,31 @@ void CollectionStatisticsDelegate::paint( QPainter *painter,
   // is collapsed
   if ( ( index.column() == 1 || index.column() == 2 ) ) {
 
-    painter->save();
+    PainterStateSaver stateSaver( painter );
 
-    int role = 0;
-    if ( index.column() == 1 ) {
-      if ( !expanded )
-        role = CollectionStatisticsModel::RecursiveUnreadRole;
-      else
-        role = CollectionStatisticsModel::UnreadRole;
-    }
-    else if ( index.column() == 2 ) {
-      if ( !expanded )
-        role = CollectionStatisticsModel::RecursiveTotalRole;
-      else
-        role = CollectionStatisticsModel::TotalRole;
-    }
-
-    QVariant sum = index.model()->data( index, role );
-    Q_ASSERT( sum.type() == QVariant::LongLong );
     QStyleOptionViewItem opt = option;
-    if ( index.column() == 1 && sum.toLongLong() > 0 ) {
+
+    QString sumText;
+    if ( index.column() == 1 && ( ( !expanded && unreadRecursiveCount > 0 ) || ( expanded && unreadCount > 0 ) ) ) {
       QFont font = painter->font();
       font.setBold( true );
       painter->setFont( font );
+      sumText = QString::number( expanded ? unreadCount : unreadRecursiveCount );
+    } else {
+
+      qint64 totalCount = statistics.count();
+      qint64 totalRecursiveCount = d->getCountRecursive<TotalCount>( index.sibling( index.row(), 0 ) );
+      if (index.column() == 2 && ( ( !expanded && totalRecursiveCount > 0 ) || ( expanded && totalCount > 0 ) ) ) {
+        sumText = QString::number( expanded ? totalCount : totalRecursiveCount );
+      }
     }
-    QString sumText;
-    if ( sum.toLongLong() <= 0 )
-      sumText = text;
-    else
-      sumText = sum.toString();
 
     painter->drawText( textRect, Qt::AlignRight, sumText );
-    painter->restore();
 
-    if ( option.state & QStyle::State_Selected ) {
-      painter->restore();
-    }
     return;
   }
 
   painter->drawText( textRect, option4.displayAlignment, text );
-
-  if ( option.state & QStyle::State_Selected ) {
-    painter->restore();
-  }
 }
 
 #include "collectionstatisticsdelegate.moc"
