@@ -19,7 +19,7 @@
 
 #include "item.h"
 #include "item_p.h"
-#include "itemserializer.h"
+#include "itemserializer_p.h"
 #include "protocol_p.h"
 
 #include <kurl.h>
@@ -65,16 +65,24 @@ void Item::setFlag( const QByteArray & name )
 {
   Q_D( Item );
   d->mFlags.insert( name );
-  if ( !d->mFlagsOverwritten )
-    d->mAddedFlags.insert( name );
+  if ( !d->mFlagsOverwritten ) {
+    if ( d->mDeletedFlags.contains( name ) )
+      d->mDeletedFlags.remove( name );
+    else
+      d->mAddedFlags.insert( name );
+  }
 }
 
 void Item::clearFlag( const QByteArray & name )
 {
   Q_D( Item );
   d->mFlags.remove( name );
-  if ( !d->mFlagsOverwritten )
-    d->mDeletedFlags.insert( name );
+  if ( !d->mFlagsOverwritten ) {
+    if ( d->mAddedFlags.contains( name ) )
+      d->mAddedFlags.remove( name );
+    else
+      d->mDeletedFlags.insert( name );
+  }
 }
 
 void Item::setFlags( const Flags &flags )
@@ -121,7 +129,12 @@ QByteArray Item::payloadData() const
 
 void Item::setPayloadFromData( const QByteArray &data )
 {
-  ItemSerializer::deserialize( *this, FullPayload, data, 0 );
+  ItemSerializer::deserialize( *this, FullPayload, data, 0, false );
+}
+
+void Item::clearPayload()
+{
+  d_func()->mClearPayload = true;
 }
 
 int Item::revision() const
@@ -134,6 +147,16 @@ void Item::setRevision( int rev )
   d_func()->mRevision = rev;
 }
 
+Entity::Id Item::storageCollectionId() const
+{
+  return d_func()->mCollectionId;
+}
+
+void Item::setStorageCollectionId( Entity::Id collectionId )
+{
+  d_func()->mCollectionId = collectionId;
+}
+
 QString Item::mimeType() const
 {
   return d_func()->mMimeType;
@@ -141,7 +164,9 @@ QString Item::mimeType() const
 
 void Item::setSize( qint64 size )
 {
-  d_func()->mSize = size;
+  Q_D( Item );
+  d->mSize = size;
+  d->mSizeChanged = true;
 }
 
 qint64 Item::size() const
@@ -162,7 +187,7 @@ bool Item::hasPayload() const
 KUrl Item::url( UrlType type ) const
 {
   KUrl url;
-  url.setProtocol( QString::fromLatin1("akonadi") );
+  url.setProtocol( QString::fromLatin1( "akonadi" ) );
   url.addQueryItem( QLatin1String( "item" ), QString::number( id() ) );
 
   if ( type == UrlWithMimeType )
@@ -197,4 +222,40 @@ void Item::setPayloadBase( PayloadBase* p )
   d->mPayload = p;
 }
 
+QSet<QByteArray> Item::availablePayloadParts() const
+{
+  return ItemSerializer::availableParts( *this );
+}
+
+void Item::apply( const Item &other )
+{
+  Q_ASSERT( mimeType() == other.mimeType() && id() == other.id() );
+  setRemoteId( other.remoteId() );
+  setRevision( other.revision() );
+  setFlags( other.flags() );
+  setModificationTime( other.modificationTime() );
+  setSize( other.size() );
+  setParentCollection( other.parentCollection() );
+  setStorageCollectionId( other.storageCollectionId() );
+  setRemoteId( other.remoteId() );
+
+  QList<QByteArray> attrs;
+  foreach ( Attribute *attribute, other.attributes() )
+  {
+    addAttribute( attribute->clone() );
+    attrs.append( attribute->type() );
+  }
+
+  QMutableHashIterator<QByteArray, Attribute*> it( d_ptr->mAttributes );
+  while ( it.hasNext() ) {
+    it.next();
+    if ( !attrs.contains( it.key() ) ) {
+      delete it.value();
+      it.remove();
+    }
+  }
+
+  ItemSerializer::apply( *this, other );
+}
+
 AKONADI_DEFINE_PRIVATE( Item )
