@@ -20,6 +20,7 @@
 #ifndef AKONADI_MONITOR_P_H
 #define AKONADI_MONITOR_P_H
 
+#include "akonadiprivate_export.h"
 #include "monitor.h"
 #include "collection.h"
 #include "collectionstatisticsjob.h"
@@ -43,7 +44,7 @@ class Monitor;
 /**
  * @internal
  */
-class MonitorPrivate
+class AKONADI_TESTS_EXPORT MonitorPrivate
 {
   public:
     MonitorPrivate( Monitor *parent );
@@ -69,31 +70,15 @@ class MonitorPrivate
     bool fetchCollection;
     bool fetchCollectionStatistics;
 
-    bool isCollectionMonitored( Collection::Id collection, const QByteArray &resource ) const
-    {
-      if ( monitorAll || isCollectionMonitored( collection ) || resources.contains( resource ) )
-        return true;
-      return false;
-    }
-
-    bool isItemMonitored( Item::Id item, Collection::Id collection, Collection::Id collectionDest,
-                          const QString &mimetype, const QByteArray &resource ) const
-    {
-      if ( monitorAll || isCollectionMonitored( collection ) ||
-           isCollectionMonitored( collectionDest ) ||items.contains( item ) ||
-           resources.contains( resource ) || isMimeTypeMonitored( mimetype ) )
-        return true;
-      return false;
-    }
-
-    bool isSessionIgnored( const QByteArray &sessionId ) const
-    {
-      return sessions.contains( sessionId );
-    }
-
-    bool connectToNotificationManager();
+    // Virtual so it can be overridden in FakeMonitor.
+    virtual bool connectToNotificationManager();
     bool acceptNotification( const NotificationMessage &msg );
     void dispatchNotifications();
+
+    // Called when the monitored item/collection changes, checks if the queued messages
+    // are still accepted, if not they are removed
+    void cleanOldNotifications();
+
     bool ensureDataAvailable( const NotificationMessage &msg );
     void emitNotification( const NotificationMessage &msg );
     void updatePendingStatistics( const NotificationMessage &msg );
@@ -209,17 +194,25 @@ class MonitorPrivate
       return false;
     }
 
+    bool isMoveDestinationResourceMonitored( const NotificationMessage &msg )
+    {
+      if ( msg.operation() != NotificationMessage::Move || msg.itemParts().isEmpty() )
+        return false;
+      const QByteArray res = *(msg.itemParts().begin());
+      return resources.contains( res );
+    }
+
     void fetchStatistics( Collection::Id colId )
     {
       CollectionStatisticsJob *job = new CollectionStatisticsJob( Collection( colId ), session );
-      QObject::connect( job, SIGNAL(result(KJob*)), q_ptr, SLOT(slotStatisticsChangedFinished(KJob*)) );
+      QObject::connect( job, SIGNAL( result( KJob* ) ), q_ptr, SLOT( slotStatisticsChangedFinished( KJob* ) ) );
     }
 
     void notifyCollectionStatisticsWatchers( Collection::Id collection, const QByteArray &resource )
     {
-      if ( isCollectionMonitored( collection, resource ) ) {
+      if ( collection > 0 && (monitorAll || isCollectionMonitored( collection ) || resources.contains( resource ) ) ) {
         if (recentlyChangedCollections.empty() )
-          QTimer::singleShot( 500, q_ptr, SLOT(slotFlushRecentlyChangedCollections()) );
+          QTimer::singleShot( 500, q_ptr, SLOT( slotFlushRecentlyChangedCollections() ) );
         recentlyChangedCollections.insert( collection );
       }
     }
