@@ -23,14 +23,14 @@
 #include "session.h"
 #include "imapparser_p.h"
 #include "akonadiprivate_export.h"
+#include "servermanager.h"
 
 #include <QtNetwork/QLocalSocket>
 
 #include <QtCore/QQueue>
-#include <QtCore/QSettings>
 #include <QtCore/QThreadStorage>
 
-class QLocalSocket;
+class QIODevice;
 
 namespace Akonadi {
 
@@ -45,15 +45,16 @@ class AKONADI_TESTS_EXPORT SessionPrivate
     virtual ~SessionPrivate()
     {
       delete parser;
-      delete mConnectionSettings;
     }
 
     virtual void init( const QByteArray &sessionId );
 
     void startNext();
     void reconnect();
+    void serverStateChanged( ServerManager::State );
     void socketDisconnected();
     void socketError( QLocalSocket::LocalSocketError error );
+    void socketError( QAbstractSocket::SocketError error );
     void dataReceived();
     void doStartNext();
     void startJob( Job* job );
@@ -95,12 +96,11 @@ class AKONADI_TESTS_EXPORT SessionPrivate
     */
     void writeData( const QByteArray &data );
 
-    static int minimumProtocolVersion() { return 23; }
+    static int minimumProtocolVersion() { return 26; }
 
     Session *mParent;
     QByteArray sessionId;
-    QSettings *mConnectionSettings;
-    QLocalSocket* socket;
+    QIODevice* socket;
     bool connected;
     int theNextTag;
     int protocolVersion;
