@@ -25,6 +25,7 @@
 #include "subscriptionchangeproxymodel_p.h"
 #include "flatcollectionproxymodel_p.h"
 #include "control.h"
+#include "krecursivefilterproxymodel.h"
 
 #include <kdebug.h>
 
@@ -52,7 +53,7 @@ class SubscriptionDialog::Private
       SubscriptionJob *job = new SubscriptionJob( q );
       job->subscribe( model->subscribed() );
       job->unsubscribe( model->unsubscribed() );
-      connect( job, SIGNAL(result(KJob*)), q, SLOT(subscriptionResult(KJob*)) );
+      connect( job, SIGNAL( result( KJob* ) ), q, SLOT( subscriptionResult( KJob* ) ) );
     }
 
     void subscriptionResult( KJob *job )
@@ -66,13 +67,13 @@ class SubscriptionDialog::Private
 
     void subscribeClicked()
     {
-      foreach( const QModelIndex &index, ui.collectionView->selectionModel()->selectedIndexes() )
+      foreach ( const QModelIndex &index, ui.collectionView->selectionModel()->selectedIndexes() )
         model->setData( index, Qt::Checked, Qt::CheckStateRole );
     }
 
     void unsubscribeClicked()
     {
-      foreach( const QModelIndex &index, ui.collectionView->selectionModel()->selectedIndexes() )
+      foreach ( const QModelIndex &index, ui.collectionView->selectionModel()->selectedIndexes() )
         model->setData( index, Qt::Unchecked, Qt::CheckStateRole );
     }
 
@@ -83,12 +84,14 @@ class SubscriptionDialog::Private
       ui.unsubscribeButton->setEnabled( true );
       ui.subscribeView->setEnabled( true );
       ui.unsubscribeView->setEnabled( true );
+      ui.collectionView->expandAll();
       q->enableButtonOk( true );
     }
 
     SubscriptionDialog* q;
     Ui::SubscriptionDialog ui;
     SubscriptionModel* model;
+    KRecursiveFilterProxyModel *filterTreeViewModel;
 };
 
 SubscriptionDialog::SubscriptionDialog(QWidget * parent) :
@@ -99,24 +102,30 @@ SubscriptionDialog::SubscriptionDialog(QWidget * parent) :
   d->ui.setupUi( mainWidget() );
   KIcon icon;
   if ( QApplication::isLeftToRight() )
-    icon = KIcon( QLatin1String("go-next") );
+    icon = KIcon( QLatin1String( "go-next" ) );
   else
-    icon = KIcon( QLatin1String("go-previous") );
+    icon = KIcon( QLatin1String( "go-previous" ) );
   d->ui.subscribeButton->setIcon( icon );
   d->ui.unsubscribeButton->setIcon( icon );
 
   d->model = new SubscriptionModel( this );
-  d->ui.collectionView->setModel( d->model );
+
+  d->filterTreeViewModel = new KRecursiveFilterProxyModel( this );
+  d->filterTreeViewModel->setDynamicSortFilter( true );
+  d->filterTreeViewModel->setSourceModel( d->model );
+  d->filterTreeViewModel->setFilterCaseSensitivity( Qt::CaseInsensitive );
+  d->ui.collectionView->setModel( d->filterTreeViewModel );
 
   d->setupChangeView( d->ui.subscribeView, true );
   d->setupChangeView( d->ui.unsubscribeView, false );
 
-  connect( d->model, SIGNAL(loaded()), SLOT(modelLoaded()) );
-  connect( d->ui.subscribeButton, SIGNAL(clicked()), SLOT(subscribeClicked()) );
-  connect( d->ui.unsubscribeButton, SIGNAL(clicked()), SLOT(unsubscribeClicked()) );
-  connect( this, SIGNAL(okClicked()), SLOT(done()) );
-  connect( this, SIGNAL(cancelClicked()), SLOT(deleteLater()) );
-
+  connect( d->model, SIGNAL( loaded() ), SLOT( modelLoaded() ) );
+  connect( d->ui.subscribeButton, SIGNAL( clicked() ), SLOT( subscribeClicked() ) );
+  connect( d->ui.unsubscribeButton, SIGNAL( clicked() ), SLOT( unsubscribeClicked() ) );
+  connect( this, SIGNAL( okClicked() ), SLOT( done() ) );
+  connect( this, SIGNAL( cancelClicked() ), SLOT( deleteLater() ) );
+  connect( d->ui.klineedit, SIGNAL( textChanged( const QString& ) ),
+           d->filterTreeViewModel, SLOT( setFilterFixedString( const QString& ) ) );
   Control::widgetNeedsAkonadi( mainWidget() );
 }
 
