@@ -41,10 +41,12 @@ class CollectionJobTest : public QObject
     void testModify_data();
     void testModify();
     void testIllegalModify();
+    void testUtf8CollectionName_data();
     void testUtf8CollectionName();
     void testMultiList();
     void testSelect();
     void testRidFetch();
+    void testRidCreateDelete_data();
     void testRidCreateDelete();
     void testAncestorRetrieval();
 };
