@@ -18,8 +18,9 @@
     02110-1301, USA.
 */
 
-#include "control.h"
 #include "itemstoretest.h"
+
+#include "control.h"
 #include "testattribute.h"
 #include <akonadi/agentmanager.h>
 #include <akonadi/agentinstance.h>
@@ -57,7 +58,7 @@ void ItemStoreTest::initTestCase()
   QVERIFY( res3.isValid() );
 
   // switch all resources offline to reduce interference from them
-  foreach ( Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances() )
+  foreach ( Akonadi::AgentInstance agent, Akonadi::AgentManager::self()->instances() ) //krazy:exclude=foreach
     agent.setIsOnline( false );
 }
 
@@ -158,8 +159,6 @@ void ItemStoreTest::testDataChange()
   QEXPECT_FAIL( "null", "STORE will not update item size on 0 sizes", Continue );
   QEXPECT_FAIL( "empty", "STORE will not update item size on 0 sizes", Continue );
   QCOMPARE( item.size(), static_cast<qint64>( data.size() ) );
-  QEXPECT_FAIL( "null", "Serializer cannot distinguish null vs. empty", Continue );
-  QCOMPARE( item.payload<QByteArray>().isNull(), data.isNull() );
 }
 
 void ItemStoreTest::testRemoteId_data()
@@ -336,8 +335,8 @@ void ItemStoreTest::testModificationTime()
   item2 = fjob->items().first();
   QCOMPARE( initialDateTime, item2.modificationTime() );
 
-  // Lets wait 5 secs.
-  QTest::qWait( 5000 );
+  // Lets wait half a second.
+  QTest::qWait( 500 );
 
   // Modify the item
   item.attribute<TestAttribute>( Item::AddIfMissing )->data = "extra";
