@@ -24,10 +24,11 @@
 #include <kdebug.h>
 #include <klocale.h>
 
+#include <QtCore/QPointer>
+#include <QtCore/QRegExp>
 #include <QtGui/QGroupBox>
 #include <QtGui/QLayout>
 #include <QtGui/QPushButton>
-#include <QtCore/QRegExp>
 
 using namespace KABC;
 
@@ -170,11 +171,13 @@ AddresseeDialog::AddresseeDialog( QWidget *parent, bool multiple )
     setInitialSize( QSize( 650, 350 ) );
   }
 
+#ifndef KDEPIM_NO_KRESOURCES
   d->mAddressBook = StdAddressBook::self( true );
   connect( d->mAddressBook, SIGNAL( addressBookChanged( AddressBook* ) ),
            SLOT( addressBookChanged() ) );
   connect( d->mAddressBook, SIGNAL( loadingFinished( Resource* ) ),
            SLOT( addressBookChanged() ) );
+#endif
 
   d->loadAddressBook();
 }
@@ -192,7 +195,7 @@ Addressee AddresseeDialog::addressee() const
     aItem = dynamic_cast<AddresseeItem *>( d->mSelectedList->topLevelItem( 0 ) );
   } else {
     QList<QTreeWidgetItem*> selected = d->mAddresseeList->selectedItems();
-    if ( selected.count() != 0 ) {
+    if ( !selected.isEmpty() ) {
       aItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
     }
   }
@@ -217,7 +220,7 @@ Addressee::List AddresseeDialog::addressees() const
     }
   } else {
     QList<QTreeWidgetItem*> selected = d->mAddresseeList->selectedItems();
-    if ( selected.count() != 0 ) {
+    if ( !selected.isEmpty() ) {
       aItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
     }
     if ( aItem ) {
@@ -230,22 +233,30 @@ Addressee::List AddresseeDialog::addressees() const
 
 Addressee AddresseeDialog::getAddressee( QWidget *parent )
 {
-  AddresseeDialog dlg( parent );
-  if ( dlg.exec() ) {
-    return dlg.addressee();
+  Addressee contact;
+
+  QPointer<AddresseeDialog> dlg = new AddresseeDialog( parent );
+  if ( dlg->exec() && dlg ) {
+    contact = dlg->addressee();
   }
 
-  return Addressee();
+  delete dlg;
+
+  return contact;
 }
 
 Addressee::List AddresseeDialog::getAddressees( QWidget *parent )
 {
-  AddresseeDialog dlg( parent, true );
-  if ( dlg.exec() ) {
-    return dlg.addressees();
+  Addressee::List contacts;
+
+  QPointer<AddresseeDialog> dlg = new AddresseeDialog( parent, true );
+  if ( dlg->exec() && dlg ) {
+    contacts = dlg->addressees();
   }
 
-  return Addressee::List();
+  delete dlg;
+
+  return contacts;
 }
 
 void AddresseeDialog::Private::loadAddressBook()
@@ -254,12 +265,14 @@ void AddresseeDialog::Private::loadAddressBook()
   mItemDict.clear();
   mAddresseeEdit->completionObject()->clear();
 
+#ifndef KDEPIM_NO_KRESOURCES
   AddressBook::Iterator it;
   for ( it = mAddressBook->begin(); it != mAddressBook->end(); ++it ) {
     AddresseeItem *item = new AddresseeItem( mAddresseeList, (*it) );
     addCompletionItem( (*it).realName(), item );
     addCompletionItem( (*it).preferredEmail(), item );
   }
+#endif
 }
 
 void AddresseeDialog::Private::addCompletionItem( const QString &str, QTreeWidgetItem *item )
@@ -290,7 +303,7 @@ void AddresseeDialog::Private::selectItem( const QString &str )
 void AddresseeDialog::Private::updateEdit()
 {
   QList<QTreeWidgetItem*> selected = mAddresseeList->selectedItems();
-  if ( selected.count() == 0 ) {
+  if ( selected.isEmpty() ) {
     return;
   }
   QTreeWidgetItem *item = selected.at( 0 );
@@ -317,7 +330,7 @@ void AddresseeDialog::Private::addSelected( QTreeWidgetItem *item )
 void AddresseeDialog::Private::removeSelected()
 {
   QList<QTreeWidgetItem*> selected = mSelectedList->selectedItems();
-  if ( selected.count() == 0 ) {
+  if ( selected.isEmpty() ) {
     return;
   }
   AddresseeItem *addrItem = dynamic_cast<AddresseeItem *>( selected.at( 0 ) );
