@@ -22,6 +22,7 @@
 
 #include "scheduler.h"
 #include "calendar.h"
+#include "calendarresources.h"
 #include "event.h"
 #include "todo.h"
 #include "freebusy.h"
@@ -255,8 +256,8 @@ bool Scheduler::acceptPublish( IncidenceBase *newIncBase,
           if ( !visitor.assign( calInc, newInc ) ) {
             kError() << "assigning different incidence types";
           } else {
-            calInc->setUid( oldUid );
             calInc->setSchedulingID( newInc->uid() );
+            calInc->setUid( oldUid );
             res = true;
           }
         }
@@ -344,8 +345,8 @@ bool Scheduler::acceptRequest( IncidenceBase *incidence,
           kError() << "assigning different incidence types";
           res = false;
         } else {
-          i->setUid( oldUid );
           i->setSchedulingID( inc->uid() );
+          i->setUid( oldUid );
         }
         deleteTransaction( incidence );
         return res;
@@ -364,7 +365,7 @@ bool Scheduler::acceptRequest( IncidenceBase *incidence,
   // in case this is an update and we didn't find the to-be-updated incidence,
   // ask whether we should create a new one, or drop the update
   if ( existingIncidences.count() > 0 || inc->revision() == 0 ||
-       KMessageBox::warningYesNo(
+       KMessageBox::questionYesNo(
          0,
          i18nc( "@info",
                 "The event, to-do or journal to be updated could not be found. "
@@ -373,10 +374,82 @@ bool Scheduler::acceptRequest( IncidenceBase *incidence,
                 "one or 'Throw away' to discard this update." ),
          i18nc( "@title", "Discard this update?" ),
          KGuiItem( i18nc( "@option", "Store" ) ),
-         KGuiItem( i18nc( "@option", "Throw away" ) ) ) == KMessageBox::Yes ) {
+         KGuiItem( i18nc( "@option", "Throw away" ) ),
+         "AcceptCantFindIncidence" ) == KMessageBox::Yes ) {
     kDebug() << "Storing new incidence with scheduling uid=" << inc->schedulingID()
              << " and uid=" << inc->uid();
-    mCalendar->addIncidence( inc );
+
+#ifndef KDEPIM_NO_KRESOURCES
+    CalendarResources *stdcal = dynamic_cast<CalendarResources *>( mCalendar );
+    if( stdcal && !stdcal->hasCalendarResources() ) {
+      KMessageBox::sorry(
+        0,
+        i18nc( "@info", "No calendars found, unable to save the invitation." ) );
+      return false;
+    }
+
+    // FIXME: This is a nasty hack, since we need to set a parent for the
+    //        resource selection dialog. However, we don't have any UI methods
+    //        in the calendar, only in the CalendarResources::DestinationPolicy
+    //        So we need to type-cast it and extract it from the CalendarResources
+    QWidget *tmpparent = 0;
+    if ( stdcal ) {
+      tmpparent = stdcal->dialogParentWidget();
+      stdcal->setDialogParentWidget( 0 );
+    }
+#endif
+
+  TryAgain:
+    bool success = false;
+#ifndef KDEPIM_NO_KRESOURCES
+    if ( stdcal )
+      success = stdcal->addIncidence( inc );
+    else
+#endif
+      success = mCalendar->addIncidence( inc );
+
+    if ( !success ) {
+#ifndef KDEPIM_NO_KRESOURCES
+      ErrorFormat *e = stdcal ? stdcal->exception() : 0;
+#else
+      ErrorFormat *e = 0;
+#endif
+
+      if ( e && e->errorCode() == KCal::ErrorFormat::UserCancel &&
+           KMessageBox::warningYesNo(
+             0,
+             i18nc( "@info",
+                    "You canceled the save operation. Therefore, the appointment will not be "
+                    "stored in your calendar even though you accepted the invitation. "
+                    "Are you certain you want to discard this invitation? " ),
+             i18nc( "@title", "Discard this invitation?" ),
+             KGuiItem( i18nc( "@option", "Discard" ) ),
+             KGuiItem( i18nc( "@option", "Go Back to Folder Selection" ) ) ) == KMessageBox::Yes ) {
+        KMessageBox::information(
+          0,
+          i18nc( "@info",
+                 "The invitation \"%1\" was not saved to your calendar "
+                 "but you are still listed as an attendee for that appointment.\n"
+                 "If you mistakenly accepted the invitation or do not plan to attend, please "
+                 "notify the organizer %2 and ask them to remove you from the attendee list.",
+                 inc->summary(), inc->organizer().fullName() ) );
+        deleteTransaction( incidence );
+        return true;
+      } else {
+        goto TryAgain;
+      }
+
+      // We can have a failure if the user pressed [cancel] in the resource
+      // selectdialog, so check the exception.
+      if ( !e ||
+           ( e && ( e->errorCode() != KCal::ErrorFormat::UserCancel &&
+                    e->errorCode() != KCal::ErrorFormat::NoWritableFound ) ) ) {
+        QString errMessage = i18nc( "@info", "Unable to save %1 \"%2\".",
+                                   i18n( inc->type() ), inc->summary() );
+        KMessageBox::sorry( 0, errMessage );
+      }
+      return false;
+    }
   }
   deleteTransaction( incidence );
   return true;
@@ -623,13 +696,31 @@ bool Scheduler::acceptReply( IncidenceBase *incidence,
 
     // send update about new participants
     if ( attendeeAdded ) {
+      bool sendMail = false;
+      if ( ev || to ) {
+        if ( KMessageBox::questionYesNo(
+               0,
+               i18nc( "@info",
+                      "An attendee was added to the incidence. "
+                      "Do you want to email the attendees an update message?" ),
+               i18nc( "@title", "Attendee Added" ),
+               KGuiItem( i18nc( "@option", "Send Messages" ) ),
+               KGuiItem( i18nc( "@option", "Do Not Send" ) ) ) == KMessageBox::Yes ) {
+          sendMail = true;
+        }
+      }
+
       if ( ev ) {
         ev->setRevision( ev->revision() + 1 );
-        performTransaction( ev, iTIPRequest );
+        if ( sendMail ) {
+          performTransaction( ev, iTIPRequest );
+        }
       }
       if ( to ) {
         to->setRevision( to->revision() + 1 );
-        performTransaction( to, iTIPRequest );
+        if ( sendMail ) {
+          performTransaction( to, iTIPRequest );
+        }
       }
     }
 
