@@ -32,8 +32,8 @@
 #include <QTimer>
 
 // KDE
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include <KDebug>
 
 using namespace MailTransport;
 
@@ -71,6 +71,9 @@ class ServerTestPrivate
     int                            secureStage;
     int                            encryptionMode;
 
+    bool                           normalPossible;
+    bool                           securePossible;
+
     void finalResult();
     void handleSMTPIMAPResponse( int type, const QString &text );
     void sendInitialCapabilityQuery( MailTransport::Socket *socket );
@@ -93,7 +96,8 @@ class ServerTestPrivate
 
 ServerTestPrivate::ServerTestPrivate( ServerTest *test )
   : q( test ), testProgress( 0 ), secureSocketFinished( false ),
-    normalSocketFinished( false ), tlsFinished( false )
+    normalSocketFinished( false ), tlsFinished( false ),
+    normalPossible( true ), securePossible( true )
 {
 }
 
@@ -176,6 +180,12 @@ void ServerTestPrivate::handleSMTPIMAPResponse( int type, const QString &text )
   }
 
   authenticationResults[type] = parseAuthenticationList( results );
+
+  // if we couldn't parse any authentication modes, default to clear-text
+  if ( authenticationResults[type].size() == 0 ) {
+    authenticationResults[type] << Transport::EnumAuthenticationType::CLEAR;
+  }
+
   kDebug() << "For type" << type << ", we have:" << authenticationResults[type];
 }
 
@@ -187,7 +197,6 @@ void ServerTestPrivate::slotNormalPossible()
 
 void ServerTestPrivate::sendInitialCapabilityQuery( MailTransport::Socket *socket )
 {
-  kDebug();
   if ( testProtocol == IMAP_PROTOCOL ) {
     socket->write( QLatin1String( "1 CAPABILITY" ) );
   }
@@ -203,7 +212,7 @@ void ServerTestPrivate::sendInitialCapabilityQuery( MailTransport::Socket *socke
       hostname = fakeHostname;
     } else {
       hostname = QHostInfo::localHostName();
-      if( hostname.isEmpty() ) {
+      if ( hostname.isEmpty() ) {
         hostname = QLatin1String( "localhost.invalid" );
       } else if ( !hostname.contains( QChar::fromAscii( '.' ) ) ) {
         hostname += QLatin1String( ".localnet" );
@@ -217,7 +226,6 @@ void ServerTestPrivate::sendInitialCapabilityQuery( MailTransport::Socket *socke
 
 void ServerTestPrivate::slotTlsDone()
 {
-  kDebug();
 
   // The server will not send a response after starting TLS. Therefore, we have to manually
   // call slotReadNormal(), because this is not triggered by a data received signal this time.
@@ -258,7 +266,7 @@ bool ServerTestPrivate::handlePopConversation( MailTransport::Socket *socket, in
   }
 
   // CAPA result
-  else if( stage == 1 ) {
+  else if ( stage == 1 ) {
 //     Example:
 //     CAPA
 //     +OK
@@ -286,7 +294,7 @@ bool ServerTestPrivate::handlePopConversation( MailTransport::Socket *socket, in
   }
 
   // AUTH response
-  else if( stage == 2 ) {
+  else if ( stage == 2 ) {
 //     Example:
 //     C: AUTH
 //     S: +OK List of supported authentication methods follows
@@ -409,6 +417,8 @@ void ServerTestPrivate::slotReadSecure( const QString &text )
 
 void ServerTestPrivate::slotNormalNotPossible()
 {
+  normalSocketTimer->stop();
+  normalPossible = false;
   normalSocketFinished = true;
   tlsFinished = true;
   finalResult();
@@ -422,6 +432,8 @@ void ServerTestPrivate::slotSslPossible()
 
 void ServerTestPrivate::slotSslNotPossible()
 {
+  secureSocketTimer->stop();
+  securePossible = false;
   secureSocketFinished = true;
   finalResult();
 }
@@ -466,6 +478,8 @@ void ServerTest::start()
   d->normalStage = -1;
   d->secureStage = -1;
   d->encryptionMode = Transport::EnumEncryption::None;
+  d->normalPossible = true;
+  d->securePossible = true;
 
   if ( d->testProgress ) {
     d->testProgress->setMaximum( 20 );
@@ -581,6 +595,11 @@ QList< int > ServerTest::normalProtocols()
   return d->authenticationResults[TransportBase::EnumEncryption::None];
 }
 
+bool ServerTest::isNormalPossible()
+{
+  return d->normalPossible;
+}
+
 QList< int > ServerTest::tlsProtocols()
 {
   return d->authenticationResults[TransportBase::EnumEncryption::TLS];
@@ -591,6 +610,11 @@ QList< int > ServerTest::secureProtocols()
   return d->authenticationResults[Transport::EnumEncryption::SSL];
 }
 
+bool ServerTest::isSecurePossible()
+{
+  return d->securePossible;
+}
+
 QList< ServerTest::Capability > ServerTest::capabilities() const
 {
   return d->capabilityResults.toList();
